@@ -1,10 +1,10 @@
 # @package      hubzero-submit-monitors
 # @file         ProbeMonitor.py
 # @author       Steven Clark <clarks@purdue.edu>
-# @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -26,8 +26,9 @@
 #
 
 import re
+import logging
 
-from hubzero.submit.LogMessage  import logID as log
+from hubzero.submit.LogMessage  import getLogIDMessage as getLogMessage
 from hubzero.submit.MessageCore import MessageCore
 
 class ProbeMonitor(MessageCore):
@@ -39,6 +40,8 @@ class ProbeMonitor(MessageCore):
                 activeProbeDumpPath="monitorProbe.dump"):
       bindLabel = "%s:%d" % (host if host else "localhost",port)
       MessageCore.__init__(self,bindHost=host,bindPort=port,bindLabel=bindLabel,repeatDelay=repeatDelay)
+
+      self.logger              = logging.getLogger(__name__)
       self.fixedBufferSize     = fixedBufferSize
       self.activeProbeDumpPath = activeProbeDumpPath
       self.activeProbes        = {}
@@ -71,23 +74,33 @@ class ProbeMonitor(MessageCore):
 
       message = self.receiveMessage(channel,self.fixedBufferSize)
       if message:
-         if re.match('[QUR]:',message):
+         if re.match('[DQUR]:',message):
             try:
                messageType,request = message.split(':')
             except:
-               log("Failed QUR message request: " + message)
+               self.logger.log(logging.ERROR,getLogMessage("Failed DQUR message request: " + message))
          else:
-            log("Failed message request: " + message)
+            self.logger.log(logging.ERROR,getLogMessage("Failed message request: " + message))
             messageType = ""
 
-         if   messageType == 'Q':                        # site Query
+         if   messageType == 'D':                        # site Delete
+            site = request.strip()
+            siteDeleted = True
+            if site in self.activeProbes:
+               try:
+                  del self.activeProbes[site]
+               except:
+                  siteDeleted = False
+                  self.logger.log(logging.ERROR,getLogMessage("delete %s failed" % (site)))
+            self.sendMessage(channel,str(siteDeleted),self.fixedBufferSize)
+         elif messageType == 'Q':                        # site Query
             site = request.strip()
             if site in self.activeProbes:
                timeEvaluated,status,waitRank = self.activeProbes[site]
             else:
                timeEvaluated,status,waitRank = ("0","FAILED","0")
             self.sendMessage(channel,timeEvaluated + " " + status + " " + waitRank,self.fixedBufferSize)
-         elif messageType == 'U':                        # update site status
+         elif messageType == 'U':                        # Update site status
             site,timeEvaluated,status,sWaitTime = request.split(',')
             waitTime = float(sWaitTime)/60.
             if   waitTime <= 5.:
@@ -133,7 +146,7 @@ class ProbeMonitor(MessageCore):
             channel.close()
             channelClosed = True
          except:
-            log("close channel failed")
+            self.logger.log(logging.ERROR,getLogMessage("close channel failed"))
 
       return(channelClosed)
 
